pub enum StateControllerRequest {
SetSystemType {
system_type: SystemType,
responder: StateControllerSetSystemTypeResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: StateControllerControlHandle,
method_type: MethodType,
},
}Expand description
Control the state of ADB.
Variants
SetSystemType
Set the current system type of ADB (e.g. device, recovery, sideload). This method updates the system type string sent to the host and initiates a reset of the USB ADB connection so that the host can discover the device again with the new system type state.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: StateControllerControlHandle
method_type: MethodTypeImplementations
Sourceimpl StateControllerRequest
impl StateControllerRequest
pub fn into_set_system_type( self, ) -> Option<(SystemType, StateControllerSetSystemTypeResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL