pub enum SystemType {
Device,
Recovery,
Sideload,
Rescue,
Bootloader,
// some variants omitted
}Expand description
Represents the device’s system type sent during the ADB connection handshake (A_CNXN). This identifies the mode the device is currently operating in to the ADB host.
The connection string in ADB, sent during the A_CNXN handshake, is structured as
<systemtype>:<serialno>:<banner>.
<systemtype>: Identifies the device’s mode and corresponds to the values inSystemType.<serialno>: The device’s serial number. This field is commonly empty.<banner>: Contains metadata about the device, such as properties like product name, model, and supported features (e.g., “ro.product.name=…”, “features=…”).
Variants
Device
The device is in normal boot.
Recovery
The device is in recovery.
Sideload
The device is in recovery sideload mode.
Rescue
The device is in recovery rescue mode.
Bootloader
The device is in bootloader.
Implementations
Sourceimpl SystemType
impl SystemType
pub fn from_primitive(prim: u32) -> Option<SystemType>
pub fn from_primitive_allow_unknown(prim: u32) -> SystemType
pub fn unknown() -> SystemType
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool