pub struct StateControllerMarker;Trait Implementations
Sourceimpl Clone for StateControllerMarker
impl Clone for StateControllerMarker
Sourcefn clone(&self) -> StateControllerMarker
fn clone(&self) -> StateControllerMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StateControllerMarker
impl Debug for StateControllerMarker
Sourceimpl DiscoverableProtocolMarker for StateControllerMarker
impl DiscoverableProtocolMarker for StateControllerMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for StateControllerMarker
impl Hash for StateControllerMarker
Sourceimpl Ord for StateControllerMarker
impl Ord for StateControllerMarker
Sourcefn cmp(&self, other: &StateControllerMarker) -> Ordering
fn cmp(&self, other: &StateControllerMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StateControllerMarker
impl PartialEq for StateControllerMarker
Sourceimpl PartialOrd for StateControllerMarker
impl PartialOrd for StateControllerMarker
Sourceimpl ProtocolMarker for StateControllerMarker
impl ProtocolMarker for StateControllerMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.hardware.adb.StateController"
const DEBUG_NAME: &'static str = "fuchsia.hardware.adb.StateController"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = StateControllerProxy
type Proxy = StateControllerProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = StateControllerRequestStream
type RequestStream = StateControllerRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = StateControllerSynchronousProxy
type SynchronousProxy = StateControllerSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for StateControllerMarker
impl Eq for StateControllerMarker
impl StructuralPartialEq for StateControllerMarker