pub struct StateControllerProxy { /* private fields */ }Implementations
Sourceimpl StateControllerProxy
impl StateControllerProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.hardware.adb/StateController.
Sourcepub fn take_event_stream(&self) -> StateControllerEventStream
pub fn take_event_stream(&self) -> StateControllerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn set_system_type(
&self,
system_type: SystemType,
) -> QueryResponseFut<StateControllerSetSystemTypeResult, DefaultFuchsiaResourceDialect>
pub fn set_system_type( &self, system_type: SystemType, ) -> QueryResponseFut<StateControllerSetSystemTypeResult, DefaultFuchsiaResourceDialect>
Set the current system type of ADB (e.g. device, recovery, sideload). This method updates the system type string sent to the host and initiates a reset of the USB ADB connection so that the host can discover the device again with the new system type state.