pub struct StateControllerSynchronousProxy { /* private fields */ }Implementations
Sourceimpl StateControllerSynchronousProxy
impl StateControllerSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<StateControllerEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<StateControllerEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn set_system_type(
&self,
system_type: SystemType,
___deadline: MonotonicInstant,
) -> Result<StateControllerSetSystemTypeResult, Error>
pub fn set_system_type( &self, system_type: SystemType, ___deadline: MonotonicInstant, ) -> Result<StateControllerSetSystemTypeResult, Error>
Set the current system type of ADB (e.g. device, recovery, sideload). This method updates the system type string sent to the host and initiates a reset of the USB ADB connection so that the host can discover the device again with the new system type state.